@@ -6,7 +6,7 @@ Mojolicious::Plugin::Bootstrap3 - Mojolicious + http://getbootstrap.com/
 
 =head1 VERSION
 
-3.3505
+3.3600
 
 =head1 DESCRIPTION
 
@@ -74,7 +74,7 @@ The reason for using this plugin is that it's very easy to customize Bootstrap,
 and make a smaller package for the user to download.
 
   use Mojolicious::Lite;
-  plugin "bootstrap3", {custom => 1};
+  plugin bootstrap3 => {custom => 1};
   get "/" => "index";
   app->start;
 
@@ -82,17 +82,21 @@ Setting C<custom> to a true value will copy C<bootstrap.scss> to your
 C<public/sass> directory. You can then edit the file and remove the parts
 you don't need.
 
-=head2 Custom javascript
+=head2 Custom JavaScript
 
 Custom list of which javascript to include can be done directly in the
 configuration:
 
-  plugin "bootstrap3", jquery => 0, js => [qw( transition.js tooltip.js )];
+  plugin bootstrap3 => {jquery => 0, js => [qw( transition.js tooltip.js )]};
 
 The config above will I<not> include jQuery, and only include "transition.js"
 and "tooltip.js" in the output C<bootstrap.js> bundle. Complete list of
 possible javascripts can be found under L</STATIC FILE STRUCTURE>.
 
+The config below on the other hand will only include jQuery and nothing else:
+
+  plugin bootstrap3 => {jquery => 1, js => []};
+
 =head2 Themes
 
 It is very simple to use a custom
@@ -103,9 +107,7 @@ fonts and styling rules in general.
 Example:
 
   # application code
-  $app->plugin(bootstrap3 => (
-    theme => {xyz => "http://example.com/_variables.scss"}
-  ));
+  plugin bootstrap3 => {theme => {xyz => "http://example.com/_variables.scss"}};
 
   # template code
   %= asset "xyz.css"
@@ -116,9 +118,7 @@ use one of the themes from bootswatch, simply specify the URL to the
 C<_bootswatch.scss> file instead of C<_variables.scss>:
 
   # application code
-  $app->plugin(bootstrap3 => (
-    theme => {paper => "https://bootswatch.com/paper/_bootswatch.scss"}
-  ));
+  plugin bootstrap3 => {theme => {paper => "https://bootswatch.com/paper/_bootswatch.scss"}};
 
   # template code
   %= asset "paper.css"
@@ -239,7 +239,7 @@ use File::Spec ();
 use Cwd        ();
 use constant DEBUG => $ENV{MOJO_ASSETPACK_DEBUG} || 0;
 
-our $VERSION = '3.3505';
+our $VERSION = '3.3600';
 our $OVERRIDE;    # ugly hack. might go away
 
 $ENV{SASS_PATH} ||= '';
@@ -329,16 +329,17 @@ See L</Themes>.
 
 sub register {
   my ($self, $app, $config) = @_;
+  my (@css, @js);
 
   $app->plugin('AssetPack') unless eval { $app->asset };
 
   $self->{sass_path} = [];
-  $config->{css} ||= [@DEFAULT_CSS_FILES];
-  $config->{js}  ||= [@DEFAULT_JS_FILES];
   $config->{custom} = 0 if $config->{theme};
-  $config->{jquery} //= 1;
 
   push @{$app->asset->source_paths}, $self->asset_path;
+  push @css, $config->{css} ? @{$config->{css}} : @DEFAULT_CSS_FILES;
+  push @js, map {"/js/bootstrap/$_"} $config->{js} ? @{$config->{js}} : @DEFAULT_JS_FILES;
+  unshift @js, '/js/jquery-1.11.0.min.js' if $config->{jquery} or (@js and $config->{jquery} // 1);
 
   if ($config->{custom}) {
     $self->_copy_files($app,
@@ -348,17 +349,14 @@ sub register {
   if ($config->{theme}) {
     $self->_generate_theme($app, $config->{theme});
   }
-  elsif (@{$config->{css}}) {
+  elsif (@css) {
     $ENV{SASS_PATH} = $self->asset_path('sass');
     warn "[BOOTSTRAP] Defining asset 'bootstrap.css' SASS_PATH=$ENV{SASS_PATH}\n" if DEBUG;
-    $app->asset('bootstrap.css' => map {"/sass/$_"} @{$config->{css}});
+    $app->asset('bootstrap.css' => map {"/sass/$_"} @css);
   }
 
-  if (@{$config->{js}}) {
-    $app->asset(
-      'bootstrap.js' => $config->{jquery} ? ('/js/jquery-1.11.0.min.js') : (),
-      map {"/js/bootstrap/$_"} @{$config->{js}},
-    );
+  if (@js) {
+    $app->asset('bootstrap.js' => @js);
   }
 }
 
